Package 'afscISS'

Title: Retrieve composition data ISS
Description: Retrieve bootstrap estimates of age/length/conditional age-at-length input sample size produced by the surveyISS package.
Authors: Pete Hulson [aut, cre] (ORCID: 000-0001-5651-2740), Ben Williams [aut] (ORCID: 000-0001-7295-2076)
Maintainer: Pete Hulson <[email protected]>
License: MIT + file LICENSE
Version: 1.0.0
Built: 2026-05-24 05:42:49 UTC
Source: https://github.com/afsc-assessments/afscISS

Help Index


Results from surveyISS package

Description

A list containing the various output dataframes from the surveyISS package

Usage

data_iss

Format

A list

A list of ISS, age/length pop'n numbers, age/length/conditional age-at-length composition, bootstrap bias, and mean length-at-age


Get stock-specific bootstrap bias results

Description

Function that retrieves bootstrap bias results

Usage

get_bias(
  species = 21720,
  region = "goa",
  comp = "age",
  sex_cat = 4,
  spec_case = NULL
)

Arguments

species

AFSC species code (default = 21720, pacific cod)

region

survey region. options are 'ai', 'ebs', 'ebs_slope', 'goa', and 'nebs' (default = 'goa')

comp

type of composition for which ISS desired. options are 'age', 'length', and 'caal'

sex_cat

sex category for which bootstrap bias desired, options are 0 (sexes combined pre-expansion), 1 (males), 2 (females), 12 (males-female comp that sums to 1), and 4 (sexes combined post-expansion) (default = 4)

spec_case

description string if getting bootstrap bias for special case. options are 'ai_subreg', 'bsre', 'dr', 'rebs', 'w_c_egoa', 'w140', 'wc_egoa' (default = NULL)

Value

a dataframe of bootstrap bias statistics


Get stock-specific composition results

Description

Function that retrieves age, length, and conditional age-at-length composition for AFSC stock assessments

Usage

get_comp(
  species = 21720,
  region = "goa",
  comp = "age",
  sex_cat = 4,
  spec_case = NULL
)

Arguments

species

AFSC species code (default = 21720, pacific cod)

region

survey region. options are 'ai', 'ebs', 'ebs_slope', 'goa', and 'nebs' (default = 'goa')

comp

type of composition desired, options are 'age', 'length', and 'caal'

sex_cat

sex category for which composition is desired. options are 0 (sexes combined pre-expansion), 1 (males), 2 (females), 12 (males-female comp that sums to 1), and 4 (sexes combined post-expansion). Note that for comp = 'caal' the only sex categories available are 0 (sexes combined), 1 (males), and 2 (females) (default = 4)

spec_case

description string if getting composition for special case. options are 'ai_subreg', 'bsre', 'dr', 'rebs', 'w_c_egoa', 'w140', 'wc_egoa' (default = NULL)

Value

a dataframe of age, length, or conditional age-at-length composition


Get stock-specific ISS results

Description

Function that retrieves composition Input Sample Size results for AFSC stock assessments

Usage

get_ISS(
  species = 21720,
  region = "goa",
  comp = "age",
  sex_cat = 4,
  spec_case = NULL
)

Arguments

species

AFSC species code (default = 21720, pacific cod)

region

survey region. options are 'ai', 'ebs', 'ebs_slope', 'goa', and 'nebs' (default = 'goa')

comp

type of composition for which ISS desired. options are 'age', 'length', and 'caal'

sex_cat

sex category for which composition ISS desired. options are 0 (sexes combined pre-expansion), 1 (males), 2 (females), 12 (males-female comp that sums to 1), and 4 (sexes combined post-expansion) (default = 4)

spec_case

description string if getting ISS for special case. options are 'ai_subreg', 'bsre', 'dr', 'rebs', 'w_c_egoa', 'w140', 'wc_egoa' (default = NULL)

Value

a dataframe of composition ISS


Get stock-specific numbers at age/length results

Description

Function that retrieves age and length pop'n numbers for AFSC stock assessments

Usage

get_popn(
  species = 21720,
  region = "goa",
  comp = "age",
  sex_cat = 4,
  spec_case = NULL
)

Arguments

species

AFSC species code (default = 21720, pacific cod)

region

survey region. options are 'ai', 'ebs', 'ebs_slope', 'goa', and 'nebs' (default = 'goa')

comp

type of pop'n numbers desired, options are 'age' and 'length'

sex_cat

sex category for which pop'n numbers desired. options are 0 (sexes combined pre-expansion), 1 (males), 2 (females), 3 (unsexed), and 4 (sexes combined post-expansion) (default = 4)

spec_case

description string if getting pop'n numbers for special case. options are 'ai_subreg', 'bsre', 'dr', 'rebs', 'w_c_egoa', 'w140', 'wc_egoa' (default = NULL)

Value

a dataframe of age or length pop'n numbers (note that age data also include mean and sd in length-at-age)


Plot stock-specific ISS results

Description

Function that plots composition Input Sample Size results for AFSC stock assessments

Usage

plot_ISS(species, region = "goa", comp = "age", sex_cat = 4, spec_case = NULL)

Arguments

species

AFSC species code

region

survey region. options are 'ai', 'ebs', 'ebs_slope', 'goa', and 'nebs' (default = 'goa')

comp

type of composition for which ISS desired. options are 'age', 'length', and 'caal'

sex_cat

sex category for which composition ISS desired. options are 0 (sexes combined pre-expansion), 1 (males), 2 (females), 12 (males-female comp that sums to 1), and 4 (sexes combined post-expansion) (default = 4)

spec_case

description string if getting ISS for special case. options are 'ai_subreg', 'bsre', 'dr', 'rebs', 'w_c_egoa', 'w140', 'wc_egoa' (default = NULL)

Value

a dataframe of composition ISS